<template>
  <el-card
    class="my-card"
    shadow="never"
    :style="`height:${outHeight};width:${outWidth};max-height:160px;min-height:135px`"
    :body-style="`height:${height};width:${width};`"
  >
    <el-carousel
      ref="carousel"
      :autoplay="false"
      indicator-position="none"
      :arrow="data.list.length > 1 ? 'always' : 'never'"
      @change="changeHandle"
    >
      <el-carousel-item v-for="(item, index) in data.list" :key="index">
        <card-item
          :data="item"
          :showType="showType"
          :fromCluster="isFromCluster"
          :searchT="searchTime"
          @detailsClick="detailsClick"
          @addToBase="toAdd"
        ></card-item>
      </el-carousel-item>
    </el-carousel>
  </el-card>
</template>

<script>
import CardItem from "./CardItem";
export default {
  components: {
    CardItem
  },
  props: {
    data: {
      type: Object,
      default: null
    },
    showType: {
      type: String,
      default: ""
    },
    height: {
      type: String,
      default: "100%"
    },
    width: {
      type: String,
      default: "100%"
    },
    outHeight: {
      type: String,
      default: "100%"
    },
    outWidth: {
      type: String,
      default: "100%"
    },
    isFromCluster:{
       type: Boolean,
      default: false
    },
    searchTime:{

    }
  },
  watch: {

  },
  data() {
    return {
      items: [],
      filled: false
    }
  },
  watch: {
    data(newVal) {
      this.len = this.data.list.length;
      if (this.len > 3) {
        this.data.list = this.data.list.slice(0, 3)
      }
    }
  },
  methods: {
    detailsClick(ev) {
      this.$emit("detailsClick", ev);
    },
    toAdd(item) {
      this.$emit("addToBase", item);
    },
    changeHandle(e) {
      // 点击切换时, 会触发该事件, 此时重新填充全部数据, 组件会重新渲染, DOM更新后根据点击的按钮,手动切换
      // filled 控制只在第一次点击时触发.然后不再干预跑马灯切换
      if (this.len > 3 && !this.filled) {
        this.items = this.data.list
        this.filled = true

        this.$nextTick(() => {
          if (e == 1) { // 点击了下一张
            this.$refs.carousel.next()
          }
          if (e == 2) { // 点击了上一张
            this.$refs.carousel.prev()
          }
        })
      }
    }
  }
};
</script>
<style lang="scss">
.my-active-card {
  border: 2px solid #ff7733 !important;
  // background: rgba(145,197,255, 0.6) !important;
}
.my-card {
  box-sizing: border-box;
  padding: 12px 10px;
  cursor: default;
  .el-carousel__arrow {
    top: 90%;
  }
  .el-carousel__arrow {
    height: 20px;
    width: 20px;
  }
  .el-carousel__arrow:hover {
    background-color: rgba(102, 102, 102);
  }
  .el-card__body {
    padding: 0px !important;
  }
  .el-card:hover {
    box-sizing: border-box;
  }
  // .el-carousel__arrow {
  //   top: inherit;
  //   bottom: 0px;
  // }
  .el-carousel {
    height: 100% !important;
    width: 100%;
    .el-carousel__container {
      height: 100% !important;
      width: 100%;
    }
  }
}
.my-card:hover {
  -webkit-box-shadow: 0px 0px 5px 1px rgba(0, 0, 0, 0.3);
  box-shadow: 0px 0px 5px 1px rgba(0, 0, 0, 0.3);
}
</style>
<style lang = "scss" scoped>
.el-carousel__container {
  height: 100% !important;
  .el-carousel__arrow {
    top: 70% !important;
  }
  .el-carousel__arrow {
    height: 20px;
    width: 20px;
  }
  .el-carousel__arrow--right {
    right: 10px !important;
  }
  .el-carousel__arrow--left {
    left: 10px !important;
  }
}
</style>
